summaryrefslogtreecommitdiff
path: root/gnu/usr.bin/binutils
diff options
context:
space:
mode:
authorDale Rahn <drahn@cvs.openbsd.org>2003-01-17 20:55:09 +0000
committerDale Rahn <drahn@cvs.openbsd.org>2003-01-17 20:55:09 +0000
commit2053e2d6e47336f52d66ca3a45e0044e653299c3 (patch)
treec7de44fc8516aa507cb350a88c3f5e100f41c2b7 /gnu/usr.bin/binutils
parentc74953a6610ab567e0d578b0efe913e513e987ae (diff)
Update comment for linker change which just committed.
Diffstat (limited to 'gnu/usr.bin/binutils')
-rw-r--r--gnu/usr.bin/binutils/bfd/elf.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/gnu/usr.bin/binutils/bfd/elf.c b/gnu/usr.bin/binutils/bfd/elf.c
index 7b1964a7023..b39fbe4d505 100644
--- a/gnu/usr.bin/binutils/bfd/elf.c
+++ b/gnu/usr.bin/binutils/bfd/elf.c
@@ -3098,8 +3098,11 @@ get_program_header_size (abfd)
return elf_tdata (abfd)->program_header_size;
}
- /* Assume we will need exactly two PT_LOAD segments: one for text
- and one for data. */
+ /* We used to assume that two PT_LOAD segments would be enough,
+ code and data, with the change to pad the PLT and GOT, this is no
+ longer true. Now there can be several PT_LOAD sections. 6 seems
+ to be enough with BSS_PLT, where we have text, data, GOT, dynamic,
+ PLT, bss */
segs = 6;
s = bfd_get_section_by_name (abfd, ".interp");